Learn R Programming

EMMIXcontrasts2 (version 0.1.2)

scores.wire: The weighted contrast

Description

This function caculates the weighted contrast W_j in order to find out the most significant dfferentially expressed genes.

Usage

scores.wire(obj,contrast=NULL)

Arguments

obj
The return list of function emmixwire
contrast
The vector of the specified contrast

Value

The vector of the statistic Wj

Details

The number of classes of samples is either two or three.

See Also

wire.init.fit,scores.wire.

Examples

Run this code

## Not run: ------------------------------------
# 
# dat <- read.table("GSE36703_37628_col.txt",header=FALSE,sep='\t')
# 
# rownames(dat) <- 1:nrow(dat)
# 
# ###normalize the rows
# x <- DoRows(dat)
# 
# set.seed(12345)
# 
# ret <-emmixwire(x,g=3,ncov=3,nvcov=1,n1=5,n2=6,n3=3,
# 		debug=1,itmax=1000,epsilon=1e-5)
# 
# ###calculate the W_j
# wj <- scores.wire(ret,contrast=c(0.5,0.5,-1))
# 
## ---------------------------------------------

Run the code above in your browser using DataLab