Rdocumentation
powered by
Learn R Programming
EMMIXcontrasts2 (version 0.1.2)
eq8.wire: Calculate the lamda values
Description
This function calculates the lamda values in equation 2.8.
Usage
eq8.wire(m,g,nb,X,W,U,V,sigma.e,sigma.b,sigma.c,nh,contrast)
Arguments
m
The number of columns in the data
g
The number of components in the mixture model
nb
The number of columns in the design matrix X
X
The design matrix X
W
The design matrix W
U
The design matrix U
V
The design matrix V
sigma.e
The covariance parameters of error item e
sigma.b
The covariance parameters of random item b
sigma.c
The covariance parameters of random item c
nh
A vector with each element as the number of genes in each cluster
contrast
The contrast vector, for example, c(1/2,1/2,-1) or c(1,0,-1), etc.
Value
A vector of lamda.
Details
The default contrast for two classes is c(1,-1), and three classes c(1/2,1/2,-1). And it is called by function
scores.wire
and
wj2.permuted
.
See Also
wj2.permuted