Usage
wire.init.fit(dat,X,qe,n,m,g,nkmeans,nrandom=0)
wire.init.reg(dat,X,qe,n,m,g,cluster)
tau.estep.wire(dat,pro,mu,sigma,n,m,g)
Arguments
dat
The dataset, an n by m numeric matrix, where n is number of observations and m the dimension of data.
n
The number of observations
g
The number of components in the mixture model
qe
The number of columns of design matrix W
cluster
A vector of integers specifying the initial partitions of the data
nkmeans
An integer to specify the number of KMEANS partitions to be used to find the best initial values.
nrandom
An integer to specify the number of random partitions to be used to find the best initial values; the default value is 0.
pro
A vector of mixing proportions pi
mu
A numeric matrix with each column corresponding to the mean.
sigma
The covaraince m by m by g array.